@@ -68,6 +68,7 @@ class NapariSTPT:
         self.optical_slices_available = None
         self.cb_correct_brightness_optical_section = None
         self.shape = None
+        self.spacing_loaded = None
 
         self.crop_start_ratio_x = None
         self.crop_size_ratio_x = None
@@ -104,7 +105,47 @@ class NapariSTPT:
 
         return volume
         
+    def MakeBoundingBox(self):
+        with napari.gui_qt():
+
+            print(self.shape)
+            print(self.slice_spacing)
+
+            output_resolution = float(self.pixel_size.text())
+            # scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution)
+
+            size_x = self.shape[0] * float(self.slice_spacing)/float(self.optical_slices) / output_resolution
+            size_y = self.shape[1]#  * output_resolution
+            size_z = self.shape[2]#  * output_resolution
+
+            line_locations = []
+            line_locations.append([[0, 0, 0], [size_x, 0, 0]])
+            line_locations.append([[size_x, 0, 0], [size_x, size_y, 0]])
+            line_locations.append([[size_x, size_y, 0], [0, size_y, 0]])
+            line_locations.append([[0, size_y, 0], [0, 0, 0]])
+
+            line_locations.append([[0, 0, size_z], [size_x, 0, size_z]])
+            line_locations.append([[size_x, 0, size_z], [size_x, size_y, size_z]])
+            line_locations.append([[size_x, size_y, size_z], [0, size_y, size_z]])
+            line_locations.append([[0, size_y, size_z], [0, 0, size_z]])
+            
+            line_locations.append([[0, 0, 0], [0, 0, size_z]])
+            line_locations.append([[size_x, 0, 0], [size_x, 0, size_z]])
+            line_locations.append([[size_x, size_y, 0], [size_x, size_y, size_z]])
+            line_locations.append([[0, size_y, 0], [0, size_y, size_z]])
+            
+            self.viewer.add_shapes(np.asarray(line_locations), name = 'bounding box',shape_type='line', edge_color = "white", edge_width = 2)
+            #triangle = np.array([[0, 0, 0], [1000, 1000, 1000], [0, 0, 1000]])
+            #polygons = [triangle]
+
+            # self.shape = self.aligned_4.shape
+            #self.viewer.add_image([self.aligned_4], name='C4', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop blue', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+            #shapes_layer = self.viewer.add_shapes(polygons, shape_type='polygon', edge_width=5,
+            #              edge_color='coral', face_color='royalblue')
+
     def Load(self, text):
+        if any(i.name == 'bounding box' for i in self.viewer.layers):
+            self.viewer.layers.remove('bounding box')
 
         try:
             self.viewer.layers.remove('C1')
@@ -267,6 +308,7 @@ class NapariSTPT:
         print("")
 
         with napari.gui_qt():
+            self.viewer.window.qt_viewer.camera._3D_camera.fov = 45
             if self.cb_C1.isChecked():
                 print("loading C1")
 
@@ -321,7 +363,8 @@ class NapariSTPT:
                 #self.aligned_1 = volume_1
                 self.aligned_1 = self.aligned_1[chop_bottom:self.aligned_1.shape[0]-chop_top,:,:]
                 self.shape = self.aligned_1.shape
-                self.viewer.add_image([self.aligned_1], name='C1', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop purple', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                # self.viewer.add_image([self.aligned_1], name='C1', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop purple', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                self.viewer.add_image([self.aligned_1], name='C1', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='bop purple', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
             if self.cb_C2.isChecked():
                 print("loading C2")
@@ -378,7 +421,8 @@ class NapariSTPT:
                 #self.aligned_2 = volume_2
                 self.aligned_2 = self.aligned_2[chop_bottom:self.aligned_2.shape[0]-chop_top,:,:]
                 self.shape = self.aligned_2.shape
-                self.viewer.add_image([self.aligned_2], name='C2', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='red', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                # self.viewer.add_image([self.aligned_2], name='C2', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='red', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                self.viewer.add_image([self.aligned_2], name='C2', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='red', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
             if self.cb_C3.isChecked():
                 print("loading C3")
@@ -434,7 +478,8 @@ class NapariSTPT:
                 #self.aligned_3 = volume_3
                 self.aligned_3 = self.aligned_3[chop_bottom:self.aligned_3.shape[0]-chop_top,:,:]
                 self.shape = self.aligned_3.shape
-                self.viewer.add_image([self.aligned_3], name='C3', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='green', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                # self.viewer.add_image([self.aligned_3], name='C3', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='green', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                self.viewer.add_image([self.aligned_3], name='C3', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='green', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
             if self.cb_C4.isChecked():
                 print("loading C4")
@@ -490,14 +535,21 @@ class NapariSTPT:
                 #self.aligned_4 = volume_4
                 self.aligned_4 = self.aligned_4[chop_bottom:self.aligned_4.shape[0]-chop_top,:,:]
                 self.shape = self.aligned_4.shape
-                self.viewer.add_image([self.aligned_4], name='C4', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop blue', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                # self.viewer.add_image([self.aligned_4], name='C4', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop blue', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
+                self.viewer.add_image([self.aligned_4], name='C4', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='bop blue', contrast_limits=[0,30])#, translate=(0, int(start_y*output_resolution), int(start_z*output_resolution)))
 
+        spacing_loaded = [float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution]
+
+        self.MakeBoundingBox()
             # create naparimovie object
             #if self.movie is None:
                 #self.movie = Movie(myviewer=self.viewer)
                 #self.movie.inter_steps = 30
 
     def LoadInRegion(self, text):
+        
+        if any(i.name == 'bounding box' for i in self.viewer.layers):
+            self.viewer.layers.remove('bounding box')
 
         print(self.viewer.layers['Shapes'].data)
         data_length = len(self.viewer.layers['Shapes'].data[0])
@@ -517,6 +569,13 @@ class NapariSTPT:
             if maxY < self.viewer.layers['Shapes'].data[0][i][2]:
                 maxY = self.viewer.layers['Shapes'].data[0][i][2]
 
+        output_resolution = float(self.pixel_size.text())
+        # minX = minX/output_resolution
+        # maxX = maxX/output_resolution
+        # minY = minY/output_resolution
+        # maxY = maxY/output_resolution
+        print("crop to: {} {} {} {}".format(minX, maxX, minY, maxY))
+
         if self.aligned_1 is not None:
             self.crop_start_ratio_x = self.aligned_1.shape[1]/minX
             self.crop_size_ratio_x = self.aligned_1.shape[1]/(maxX-minX)
@@ -545,6 +604,8 @@ class NapariSTPT:
         self.Load(text)
         self.crop = False
 
+        # self.MakeBoundingBox()
+
     def Load2D(self, text):
 
         print(self.search_folder.text() +
@@ -991,129 +1052,17 @@ class NapariSTPT:
         #    if self.cb_C2.isChecked():
         #        self.viewer.add_image([self.aligned_2], name='C2 processed', scale=(15,output_resolution,output_resolution), blending='additive', colormap='red')
 
+
+
     def Remove_Small_Regions(self):
         self.Remove_Regions(True)
 
     def Keep_n_Regions(self):
         self.Remove_Regions(False)
 
-    def Crop(self):
-
-        output_resolution = float(self.pixel_size.text())
-        threshold = float(self.thresholdN.text())
-
-        maxX_final = 0
-        minX_final = sys.maxsize
-        maxY_final = 0
-        minY_final = sys.maxsize
-        maxZ_final = 0
-        minZ_final = sys.maxsize
-
-        if self.aligned_1 is not None and self.cb_C1.isChecked() and any(i.name == 'C1' for i in self.viewer.layers):
-
-            tissue = self.aligned_1 > threshold
-            objs = ndimage.find_objects(tissue)
-            maxX = int(objs[0][0].stop)
-            minX = int(objs[0][0].start)
-            maxY = int(objs[0][1].stop)
-            minY = int(objs[0][1].start)
-            maxZ = int(objs[0][2].stop)
-            minZ = int(objs[0][2].start)
-
-            maxX_final = max(maxX_final, maxX)
-            minX_final = min(minX_final, minX)
-            maxY_final = max(maxY_final, maxY)
-            minY_final = min(minY_final, minY)
-            maxZ_final = max(maxZ_final, maxZ)
-            minZ_final = min(minZ_final, minZ)
-
-        if self.aligned_2 is not None and self.cb_C2.isChecked() and any(i.name == 'C2' for i in self.viewer.layers):
-
-            print(self.aligned_2.shape)
-
-            tissue = self.aligned_2 > threshold
-            objs = ndimage.find_objects(tissue)
-            maxX = int(objs[0][0].stop)
-            minX = int(objs[0][0].start)
-            maxY = int(objs[0][1].stop)
-            minY = int(objs[0][1].start)
-            maxZ = int(objs[0][2].stop)
-            minZ = int(objs[0][2].start)
-
-            maxX_final = max(maxX_final, maxX)
-            minX_final = min(minX_final, minX)
-            maxY_final = max(maxY_final, maxY)
-            minY_final = min(minY_final, minY)
-            maxZ_final = max(maxZ_final, maxZ)
-            minZ_final = min(minZ_final, minZ)
-
-        if self.aligned_3 is not None and self.cb_C3.isChecked() and any(i.name == 'C3' for i in self.viewer.layers):
-
-            tissue = self.aligned_3 > threshold
-            objs = ndimage.find_objects(tissue)
-            maxX = int(objs[0][0].stop)
-            minX = int(objs[0][0].start)
-            maxY = int(objs[0][1].stop)
-            minY = int(objs[0][1].start)
-            maxZ = int(objs[0][2].stop)
-            minZ = int(objs[0][2].start)
-
-            maxX_final = max(maxX_final, maxX)
-            minX_final = min(minX_final, minX)
-            maxY_final = max(maxY_final, maxY)
-            minY_final = min(minY_final, minY)
-            maxZ_final = max(maxZ_final, maxZ)
-            minZ_final = min(minZ_final, minZ)
-
-        if self.aligned_4 is not None and self.cb_C4.isChecked() and any(i.name == 'C4' for i in self.viewer.layers):
-
-            tissue = self.aligned_4 > threshold
-            objs = ndimage.find_objects(tissue)
-            maxX = int(objs[0][0].stop)
-            minX = int(objs[0][0].start)
-            maxY = int(objs[0][1].stop)
-            minY = int(objs[0][1].start)
-            maxZ = int(objs[0][2].stop)
-            minZ = int(objs[0][2].start)
-
-            maxX_final = max(maxX_final, maxX)
-            minX_final = min(minX_final, minX)
-            maxY_final = max(maxY_final, maxY)
-            minY_final = min(minY_final, minY)
-            maxZ_final = max(maxZ_final, maxZ)
-            minZ_final = min(minZ_final, minZ)
-
-        print("cropping to {}-{},{}-{}".format(minX_final,
-              maxX_final, minY_final, maxY_final))
-
-        if self.aligned_1 is not None and self.cb_C1.isChecked() and any(i.name == 'C1' for i in self.viewer.layers):
-            self.aligned_1 = self.aligned_1[minX_final:maxX_final,
-                                            minY_final:maxY_final, minZ_final:maxZ_final]
-            self.viewer.layers.remove('C1')
-            self.viewer.add_image([self.aligned_1], name='C1', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='bop purple', contrast_limits=[0,30])
-        if self.aligned_2 is not None and self.cb_C2.isChecked() and any(i.name == 'C2' for i in self.viewer.layers):
-            self.aligned_2 = self.aligned_2[minX_final:maxX_final,
-                                            minY_final:maxY_final, minZ_final:maxZ_final]
-            self.viewer.layers.remove('C2')
-            self.viewer.add_image([self.aligned_2], name='C2', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='red', contrast_limits=[0,30])
-        if self.aligned_3 is not None and self.cb_C3.isChecked() and any(i.name == 'C3' for i in self.viewer.layers):
-            self.aligned_3 = self.aligned_3[minX_final:maxX_final,
-                                            minY_final:maxY_final, minZ_final:maxZ_final]
-            self.viewer.layers.remove('C3')
-            self.viewer.add_image([self.aligned_3], name='C3', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='green', contrast_limits=[0,30])
-        if self.aligned_4 is not None and self.cb_C4.isChecked() and any(i.name == 'C4' for i in self.viewer.layers):
-            self.aligned_4 = self.aligned_4[minX_final:maxX_final,
-                                            minY_final:maxY_final, minZ_final:maxZ_final]
-            self.viewer.layers.remove('C4')
-            self.viewer.add_image([self.aligned_4], name='C4', scale=(
-                15, output_resolution, output_resolution), blending='additive', colormap='bop blue', contrast_limits=[0,30])
-
-        self.viewer.layers.remove('Shapes')
-        
     def CropToRegion(self):
+        if any(i.name == 'bounding box' for i in self.viewer.layers):
+            self.viewer.layers.remove('bounding box')
 
         output_resolution = float(self.pixel_size.text())
         #print(self.viewer.layers['Shapes'])
@@ -1121,6 +1070,8 @@ class NapariSTPT:
         #print(self.viewer.layers.selection[0])
         data_length = len(self.viewer.layers['Shapes'].data[0])
         print(data_length)
+        #data_length = len(self.viewer.layers['bounding box'].data[0])
+        #print(data_length)
         minX = 100000000
         maxX = 0
         minY = 100000000
@@ -1136,35 +1087,44 @@ class NapariSTPT:
             if maxY < self.viewer.layers['Shapes'].data[0][i][2]:
                 maxY = self.viewer.layers['Shapes'].data[0][i][2]
 
+        #minX = minX/output_resolution
+        #maxX = maxX/output_resolution
+        #minY = minY/output_resolution
+        #maxY = maxY/output_resolution
         print("crop to: {} {} {} {}".format(minX, maxX, minY, maxY))
 
         if self.aligned_1 is not None and self.cb_C1.isChecked() and any(i.name == 'C1' for i in self.viewer.layers):
             self.aligned_1 = self.aligned_1[:, int(
                 minX):int(maxX), int(minY):int(maxY)]
+            self.shape = self.aligned_1.shape
             self.viewer.layers.remove('C1')
             self.image_translation = (int(minX*output_resolution), int(minY*output_resolution))
-            self.viewer.add_image([self.aligned_1], name='C1', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop purple')#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
+            self.viewer.add_image([self.aligned_1], name='C1', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='bop purple', contrast_limits=[0,30])#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
         if self.aligned_2 is not None and self.cb_C2.isChecked() and any(i.name == 'C2' for i in self.viewer.layers):
             self.aligned_2 = self.aligned_2[:, int(
                 minX):int(maxX), int(minY):int(maxY)]
+            self.shape = self.aligned_2.shape
             self.viewer.layers.remove('C2')
             self.image_translation = (int(minX*output_resolution), int(minY*output_resolution))
-            self.viewer.add_image([self.aligned_2], name='C2', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='red')#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
+            self.viewer.add_image([self.aligned_2], name='C2', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='red', contrast_limits=[0,30])#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
         if self.aligned_3 is not None and self.cb_C3.isChecked() and any(i.name == 'C3' for i in self.viewer.layers):
             self.aligned_3 = self.aligned_3[:, int(
                 minX):int(maxX), int(minY):int(maxY)]
+            self.shape = self.aligned_3.shape
             self.viewer.layers.remove('C3')
             self.image_translation = (int(minX*output_resolution), int(minY*output_resolution))
-            self.viewer.add_image([self.aligned_3], name='C3', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='green')#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
+            self.viewer.add_image([self.aligned_3], name='C3', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='green', contrast_limits=[0,30])#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
         if self.aligned_4 is not None and self.cb_C4.isChecked() and any(i.name == 'C4' for i in self.viewer.layers):
             self.aligned_4 = self.aligned_4[:, int(
                 minX):int(maxX), int(minY):int(maxY)]
+            self.shape = self.aligned_4.shape
             self.viewer.layers.remove('C4')
             self.image_translation = (int(minX*output_resolution), int(minY*output_resolution))
-            self.viewer.add_image([self.aligned_4], name='C4', scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution), blending='additive', colormap='bop blue')#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
-            
+            self.viewer.add_image([self.aligned_4], name='C4', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='bop blue', contrast_limits=[0,30])#, translate=(0, int(minX*output_resolution), int(minY*output_resolution)))
+
             
         self.viewer.layers.remove('Shapes')
+        self.MakeBoundingBox()
 
                 
     def add_polygon_simple(self):
@@ -1192,11 +1152,11 @@ class NapariSTPT:
 
         #print("pos {}".format(self.viewer.dims.point[0]))
 
-
+        output_resolution = float(self.pixel_size.text())
         
 
         #pos = float(self.viewer.cursor.position[0]/(float(self.slice_spacing)/float(self.optical_slices)))
-        pos = self.viewer.dims.point[0] / (float(self.slice_spacing)/float(self.optical_slices))
+        pos = self.viewer.dims.point[0] / ((float(self.slice_spacing)/float(self.optical_slices)) / output_resolution)
         print("pos {}".format(pos))
         
         data_length = len(self.viewer.layers['Shapes'].data[0])
@@ -1235,6 +1195,12 @@ class NapariSTPT:
                 y = float(contour_list_sorted[0][1][i][1])
                 z = float(contour_list_sorted[0][1][i][2])
 
+                # 
+                # y = y/output_resolution
+                # z = z/output_resolution
+
+                print(f"x {x}, y {y}, z {z}")
+
                 new_shape.append((x,y,z))
 
         elif pos > contour_list_sorted[len(contour_list_sorted)-1][0]:
@@ -1243,6 +1209,13 @@ class NapariSTPT:
                 y = float(contour_list_sorted[len(contour_list_sorted)-1][1][i][1])
                 z = float(contour_list_sorted[len(contour_list_sorted)-1][1][i][2])
 
+                
+                # output_resolution = float(self.pixel_size.text())
+                # y = y/output_resolution
+                # z = z/output_resolution
+
+                print(f"x {x}, y {y}, z {z}")
+
                 new_shape.append((x,y,z))
             
         else:
@@ -1273,7 +1246,7 @@ class NapariSTPT:
 
         new_shape = np.array(new_shape)
         output_resolution = float(self.pixel_size.text())
-        shapes_layer = self.viewer.add_shapes(new_shape, shape_type='polygon', name = "Shapes", scale=(float(self.slice_spacing)/float(self.optical_slices), output_resolution, output_resolution),)
+        shapes_layer = self.viewer.add_shapes(new_shape, shape_type='polygon', name = "Shapes", scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1),)
     
 
 
@@ -1306,6 +1279,7 @@ class NapariSTPT:
                 z_pos = self.viewer.layers[layer_name].data[0][0][0] # z pos
                 contour = self.viewer.layers[layer_name].data[0]
                 contour_list.append((z_pos,contour))
+                self.viewer.layers[layer_name].visible = False
                 i = i+1
             except:
                 break
@@ -1380,20 +1354,24 @@ class NapariSTPT:
                 aligned4_tmp[z_level,:,:] = aligned4_tmp[z_level,:,:] * mask
 
         
-        #self.viewer.layers.remove('C3')
            
 
-
         if self.aligned_1 is not None:
-            self.viewer.add_image([aligned1_tmp], name='C1_masked', scale=(15, output_resolution, output_resolution), blending='additive', colormap='bop purple', translate=(0, 0, 0))
+            self.viewer.add_image([aligned1_tmp], name='C1_masked', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='bop purple', contrast_limits=[0,30])
         if self.aligned_2 is not None:
-            self.viewer.add_image([aligned2_tmp], name='C2_masked', scale=(15, output_resolution, output_resolution), blending='additive', colormap='red', translate=(0, 0, 0))
+            self.viewer.add_image([aligned2_tmp], name='C2_masked', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='red', contrast_limits=[0,30])
         if self.aligned_3 is not None:
-            self.viewer.add_image([aligned3_tmp], name='C3_masked', scale=(15, output_resolution, output_resolution), blending='additive', colormap='green', translate=(0, 0, 0))
+            self.viewer.add_image([aligned3_tmp], name='C3_masked', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='green', contrast_limits=[0,30])
         if self.aligned_4 is not None:
-            self.viewer.add_image([aligned4_tmp], name='C4_masked', scale=(15, output_resolution, output_resolution), blending='additive', colormap='bop blue', translate=(0, 0, 0))
+            self.viewer.add_image([aligned4_tmp], name='C4_masked', scale=(float(self.slice_spacing)/float(self.optical_slices) / output_resolution, 1, 1), blending='additive', colormap='bop blue', contrast_limits=[0,30])
 
+        self.viewer.layers['C1'].visible = False
+        self.viewer.layers['C2'].visible = False
+        self.viewer.layers['C3'].visible = False
+        self.viewer.layers['C4'].visible = False
+        self.viewer.layers['Shapes'].visible = False
 
+        #self.viewer.layers.remove('C3')
         #self.viewer.layers.remove('Shapes')
 
 
@@ -1417,11 +1395,25 @@ class NapariSTPT:
     def on_combobox_changed(self):
         if os.path.exists(self.search_folder.text() + str(self.comboBoxPath.currentText())+'/mos.zarr/.zmetadata'):
             print("metadata is available")
-            ds = xr.open_zarr(self.search_folder.text(
-            ) + str(self.comboBoxPath.currentText())+'/mos.zarr', consolidated=True)
-            # print(ds.attrs["cube_reg"]['slice'])
-            length = len(ds.attrs["multiscale"]['datasets'])
             
+            try:
+                ds = xr.open_zarr(self.search_folder.text(
+                    ) + str(self.comboBoxPath.currentText())+'/mos.zarr', consolidated=True)
+                print("")
+                print("")
+                print(ds.attrs['sections'])
+                print("")
+                print("")
+                length = int(ds.attrs['sections'])
+
+                self.scroll.setValue(0)
+                self.image_slice.setText("0")
+                self.slice_names = ds.attrs['cube_reg']['slice']
+                self.scroll.setRange(0, len(self.slice_names))
+                print(f"number of slices: {len(self.slice_names)}")
+            except Exception:
+                print("none-consolidated")
+                pass
             #self.comboBoxResolution.clear()
             #for n in range(0, length):
             #    print("adding resolution {}".format(
@@ -1430,16 +1422,9 @@ class NapariSTPT:
             #        str(ds.attrs["multiscale"]['datasets'][n]['level']))
             #    self.comboBoxResolution.setCurrentText(
             #        str(ds.attrs["multiscale"]['datasets'][n]['level']))
-            try:
-                self.scroll.setValue(0)
-                self.image_slice.setText("0")
-                self.slice_names = ds.attrs['cube_reg']['slice']
-                self.scroll.setRange(0, len(self.slice_names))
-            except Exception:
-                # print("not initialised")
-                pass
+            
         else:
-            print("adding default resolution")
+            print("not changing number of slices")
             #self.comboBoxResolution.clear()
             #self.comboBoxResolution.addItem(str(1))
             #self.comboBoxResolution.addItem(str(2))
